@@ -1,6 +1,7 @@
 """Home of the auth modules that govern access via Eve."""
 import os
 import logging
+import jwt
 
 LOG = logging.getLogger('auth')
 
@@ -10,7 +11,6 @@ SETTINGS = {
     'ES_AUTH_REALM': os.environ.get('ES_AUTH_REALM', '{$project_name}.cri.com'),
 
     'ES_AUTH_JWT_DOMAIN': os.environ.get('ES_AUTH_JWT_DOMAIN', '{$project_name}.us.auth0.com'),
-    'ES_AUTH_JWT_CLIENT_ID': os.environ.get('ES_AUTH_JWT_CLIENT_ID', '--your-client_id--'),
     'ES_AUTH_JWT_ISSUER': os.environ.get('ES_AUTH_JWT_ISSUER', 'https://{$project_name}.us.auth0.com/'),
     'ES_AUTH_JWT_AUDIENCE': os.environ.get('ES_AUTH_JWT_AUDIENCE', 'https://cri.com/{$project_name}'),
 
@@ -20,16 +20,14 @@ SETTINGS = {
     'AUTH0_TOKEN_ENDPOINT': os.environ.get('AUTH0_TOKEN_ENDPOINT', 'https://{$project_name}.us.auth0.com/oauth/token'),
     'AUTH0_CLIENT_ID': os.environ.get('AUTH0_CLIENT_ID', '--your-client-id--'),
     'AUTH0_CLIENT_SECRET': os.environ.get('AUTH0_CLIENT_SECRET',
-                                          '--your-client-secret--'),
-                                          
-    # NOTE: AUTH0_PUBLIC_KEY cannot be set by envar
-    'AUTH0_PUBLIC_KEY': b'''
------BEGIN PUBLIC KEY-----
-    --your-public-key--
------END PUBLIC KEY-----
-'''
+                                          '--your-client-secret--')
 }
 
+JWK_CLIENT = jwt.PyJWKClient(f'https://{SETTINGS["ES_AUTH_JWT_DOMAIN"]}/.well-known/jwks.json')
+_jwks = JWK_CLIENT.get_signing_keys()
+SIGNING_KEYS = {jwk.key_id: jwk.key for jwk in _jwks}
+
+
 # cancellable
 if SETTINGS['ES_AUTH_JWT_AUDIENCE'] == '':
     del SETTINGS['ES_AUTH_JWT_AUDIENCE']
